"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const CommandUtil_1 = require("./CommandUtil");
const Logger_1 = require("../Logger");
const Commands_1 = require("../constants/Commands");
const Endpoints_1 = require("../constants/Endpoints");
const MCUtil = require("../MCUtil");
const UserProjectCreator_1 = require("../microclimate/connection/UserProjectCreator");
/**
 * @param create true for Create page, false for Import page
 */
function openCreateOrImportPage(connection, create) {
    return __awaiter(this, void 0, void 0, function* () {
        Logger_1.default.d("openCreateOrImportPage invoked, create=" + create);
        if (connection == null) {
            const selected = yield CommandUtil_1.promptForConnection(true);
            if (selected == null) {
                Logger_1.default.d("User cancelled prompt for resource");
                // user cancelled
                return;
            }
            connection = selected;
        }
        try {
            if (create && connection.is1905OrNewer()) {
                // we get to use the new creation feature
                yield UserProjectCreator_1.default.createProject(connection);
            }
            else {
                yield deprecatedNewProject(connection, create);
            }
        }
        catch (err) {
            Logger_1.default.e("Error creating project", err);
            vscode.window.showErrorMessage("Error creating project: " + MCUtil.errToString(err));
        }
    });
}
exports.default = openCreateOrImportPage;
function deprecatedNewProject(connection, create) {
    return __awaiter(this, void 0, void 0, function* () {
        const newProjectUrl = Endpoints_1.default.resolveCreateOrImportUrl(connection, create);
        Logger_1.default.i(`${create ? "Create" : "Import"} new Microclimate project at ${newProjectUrl}`);
        return vscode.commands.executeCommand(Commands_1.default.VSC_OPEN, newProjectUrl);
    });
}
//# sourceMappingURL=CreateUserProjectCmd.js.map