"use strict";
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const request = require("request-promise-native");
const Logger_1 = require("../../Logger");
const Endpoints_1 = require("../../constants/Endpoints");
/**
 * Functions to create or import new user projects into Microclimate
 */
var ProjectCreator;
(function (ProjectCreator) {
    function createProject(connection) {
        return __awaiter(this, void 0, void 0, function* () {
            const projectTypesUrl = Endpoints_1.default.resolveMCEndpoint(connection, Endpoints_1.MCEndpoints.PROJECT_TYPES);
            const projectTypes = yield request.get(projectTypesUrl, { json: true });
            const projectTypeQpis = projectTypes.map((type) => {
                return {
                    label: type.label,
                    description: type.description,
                    // detail: type.extension,
                    detail: type.language,
                    language: type.language,
                    extension: type.extension,
                };
            });
            const projectTypeSelected = yield vscode.window.showQuickPick(projectTypeQpis, {
                placeHolder: "Select the project type to create",
                // matchOnDescription: true,
                matchOnDetail: true,
            });
            if (projectTypeSelected == null) {
                return;
            }
            const projectName = yield getProjectName(projectTypeSelected.description);
            if (projectName == null) {
                return;
            }
            return issueCreateReq(connection, projectTypeSelected, projectName);
        });
    }
    ProjectCreator.createProject = createProject;
    function issueCreateReq(connection, projectTypeSelected, projectName) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = {
                language: projectTypeSelected.language,
                // metrics: true       // portal-ui sends this, why?
                name: projectName,
                extension: projectTypeSelected.extension // note: null for nodejs right now
            };
            const creationRes = yield request.post(Endpoints_1.default.resolveMCEndpoint(connection, Endpoints_1.MCEndpoints.PROJECTS_V2), {
                json: true,
                body: payload,
            });
            Logger_1.default.i(creationRes);
            vscode.window.showInformationMessage(`Creating ${payload.language} project ${projectName}`);
        });
    }
    ProjectCreator.issueCreateReq = issueCreateReq;
    function getProjectName(projectTypeName) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield vscode.window.showInputBox({
                placeHolder: `Enter a name for your new ${projectTypeName ? projectTypeName + " " : ""}project`,
                validateInput: (input) => {
                    const matches = /^[a-z0-9]+$/.test(input);
                    if (!matches) {
                        return `Invalid project name "${input}". Project name can only contain numbers and lowercase letters.`;
                    }
                    return undefined;
                }
            });
        });
    }
})(ProjectCreator || (ProjectCreator = {}));
exports.default = ProjectCreator;
//# sourceMappingURL=UserProjectCreator.js.map