"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const ConnectionManager_1 = require("../microclimate/connection/ConnectionManager");
// import Commands from "../constants/Commands";
const Logger_1 = require("../Logger");
const Project_1 = require("../microclimate/project/Project");
const Connection_1 = require("../microclimate/connection/Connection");
const TreeItemFactory_1 = require("./TreeItemFactory");
// const STRING_NS = StringNamespaces.TREEVIEW;
class ProjectTreeDataProvider {
    constructor() {
        this.VIEW_ID = "ext.mc.mcProjectExplorer"; // must match package.nls.json
        this.onTreeDataChangeEmitter = new vscode.EventEmitter();
        this.onDidChangeTreeData = this.onTreeDataChangeEmitter.event;
        /**
         * Notifies VSCode that this tree has to be refreshed.
         * Used as a call-back for ConnectionManager OnChange.
         */
        this.refresh = (treeItem) => {
            // Log.d("refresh tree");
            this.onTreeDataChangeEmitter.fire(treeItem);
        };
        this.treeView = vscode.window.createTreeView(this.VIEW_ID, { treeDataProvider: this });
        ConnectionManager_1.default.instance.addOnChangeListener(this.refresh);
        Logger_1.default.d("Finished constructing ProjectTree");
        // this.treeView.onDidChangeSelection((e) => {
        //     Log.d("Selection is now", e.selection[0]);
        // });
    }
    getTreeItem(node) {
        if (node instanceof Project_1.default || node instanceof Connection_1.default) {
            return TreeItemFactory_1.default.toTreeItem(node);
        }
        return node;
    }
    getChildren(node) {
        if (node == null) {
            // root
            // connections are the top-level tree items
            return TreeItemFactory_1.default.getRootTreeItems();
        }
        else if (node instanceof Connection_1.default) {
            return TreeItemFactory_1.default.getConnectionChildren(node);
        }
        // projects have no children
        return [];
    }
    getParent(node) {
        if (node instanceof Project_1.default) {
            return node.connection;
        }
        else if (node instanceof Connection_1.default) {
            return undefined;
        }
        Logger_1.default.e("Unexpected TreeItem!", node);
        return undefined;
    }
}
exports.default = ProjectTreeDataProvider;
//# sourceMappingURL=ProjectTree.js.map